// $Id: CustomSlider.cpp,v 1.9 2009/04/18 18:28:05 hpereira Exp $

/******************************************************************************
*                         
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>             
*                         
* This is free software; you can redistribute it and/or modify it under the    
* terms of the GNU General Public License as published by the Free Software    
* Foundation; either version 2 of the License, or (at your option) any later   
* version.                             
*                          
* This software is distributed in the hope that it will be useful, but WITHOUT 
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or        
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License        
* for more details.                     
*                          
* You should have received a copy of the GNU General Public License along with 
* software; if not, write to the Free Software Foundation, Inc., 59 Temple     
* Place, Suite 330, Boston, MA  02111-1307 USA                           
*                         
*                         
*******************************************************************************/
 
/*!
  \file CustomSlider.cpp
  \brief customized QSlider associated to a LineEditor
  \author Hugo Pereira
  \version $Revision: 1.9 $
  \date $Date: 2009/04/18 18:28:05 $
*/

#include <QHBoxLayout>


#include "CustomSlider.h"
#include "Debug.h"
#include "InformationDialog.h"
#include "Str.h"

using namespace std;

//_________________________________________________________
CustomSlider::CustomSlider( QWidget* parent ):
  QWidget( parent ),
  Counter( "CustomSlider" )
{  
  Debug::Throw( "CustomSlider::CustomSlider.\n" );
  
  setLayout( new QHBoxLayout() );
  layout()->setMargin(0);
  layout()->setSpacing(5);
  
  layout()->addWidget( slider_ = new QSlider( Qt::Horizontal, this ) );
  layout()->addWidget( line_edit_ = new AnimatedLineEditor( this ) );
  line_edit_->setHasClearButton( false );
  
  connect( line_edit_, SIGNAL( returnPressed() ),   SLOT( _updateSlider() ) );
  connect( slider_, SIGNAL( valueChanged( int ) ),  SLOT( _updateLineEdit( int ) ) );

  line_edit_->setMaximumSize( QSize( 
    line_edit_->fontMetrics().width("  -100  "), 
    line_edit_->height()) );

}

//_________________________________________________________
void CustomSlider::setValue( int value )
{
  if( value < slider_->minimum() || value > slider_->maximum() ) {
    InformationDialog( this, "invalid value" ).exec();
    return;
  }
  
  slider_->setValue( value );
  _updateLineEdit( value );
}

//_________________________________________________________
void CustomSlider::_updateSlider( void )
{  
  Debug::Throw( "CustomSlider::_updateSlider.\n" );
  
  // retrieve/check text from line_edit_
  bool error( false );
  int value( Str( line_edit_->text() ).get<int>(&error) );
  if( error || value < slider_->minimum() || value > slider_->maximum() ) 
  {
    InformationDialog( this, "invalid value" ).exec();
    return;
  }
  
  slider_->setValue( value );
  return;
}

//_________________________________________________________
void CustomSlider::_updateLineEdit( int value )
{
  Debug::Throw( "CustomSlider::_updateLineEdit.\n" );
  line_edit_->setText( QString().setNum( value ) );
  return;
}
