// $Id: MainWindow.h,v 1.9 2009/04/20 14:18:52 hpereira Exp $

/******************************************************************************
*                         
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>             
*                         
* This is free software; you can redistribute it and/or modify it under the    
* terms of the GNU General Public License as published by the Free Software    
* Foundation; either version 2 of the License, or (at your option) any later   
* version.                             
*                          
* This software is distributed in the hope that it will be useful, but WITHOUT 
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or        
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License        
* for more details.                     
*                          
* You should have received a copy of the GNU General Public License along with 
* software; if not, write to the Free Software Foundation, Inc., 59 Temple     
* Place, Suite 330, Boston, MA  02111-1307 USA                           
*                         
*                         
*******************************************************************************/
#ifndef _MainWindow_h_
#define _MainWindow_h_
 
/*!
  \file MainWindow.h
  \brief customized QVBox to recieve close event
  \author Hugo Pereira
  \version $Revision: 1.9 $
  \date $Date: 2009/04/20 14:18:52 $
*/

#include <QAction>
#include <QCloseEvent>

#include <assert.h>

#include <vector>

#include "Counter.h"  
#include "BaseMainWindow.h"  
#include "Debug.h"
#include "ServerCommand.h"  
#include "ServerCommandModel.h"

class CustomToolBar;
class TreeView;
class Menu;
class StatusBar;

/*!
  \class MainWindow
  \brief customized QVBox to recieve close event
*/
class MainWindow: public BaseMainWindow
{

  //! Qt meta object declaration
  Q_OBJECT

  public:

  //! high verbosity
  static const QString VERBOSITY_HIGH;
  
  //! low verbosity
  static const QString VERBOSITY_LOW;
  
  //! constructor
  MainWindow( QWidget* parent = 0 );  
  
  //! verbosity enumeration
  enum Verbosity
  { LOW, HIGH };
    
  //! Verbosity
  void setVerbosity( const QString& value )
  { 
    if( value == VERBOSITY_HIGH ) verbosity_ = HIGH;
    else if( value == VERBOSITY_LOW ) verbosity_ = LOW;
    else assert(0);
  }
  
  //! menu
  Menu& menu( void )
  {
    assert( menu_ );
    return *menu_;
  }
 
  //! command model
  ServerCommandModel& model( void ) 
  { return model_; }
  
  //! command list
  TreeView& list( void ) const
  { 
    assert( list_ );
    return *list_; 
  }	
  
  //! statusBar
  StatusBar& statusBar( void )
  { 
    assert( statusbar_ );
    return *statusbar_;
  }

  //! toolbar
  CustomToolBar& toolBar( void ) const
  {
    assert( toolbar_ );
    return *toolbar_;
  }
  
  //! append command to list
  void append( const ServerCommandModel::Set& );
  
  //!@name actions
  //@{
  
  //! reset action
  QAction& resetAction( void ) const
  { return *reset_action_; }

  //! unlock action
  QAction& unlockAction( void ) const
  { return *unlock_action_; }

  //! raise action
  QAction& raiseAction( void ) const
  { return *raise_action_; }
  
  //! raise action
  QAction& abortAction( void ) const
  { return *abort_action_; }
  
  //@}
  
  signals:
  
  //! request command to be passed to application application manager
  /*! the application ID corresponds to "this" application */
  void requestCommand( SERVER::ServerCommand::CommandType );
  
  //! request command to be passed to application application manager
  void requestCommand( SERVER::ServerCommand );
  
  protected:
  
  //! close window event handler
  void closeEvent( QCloseEvent *event );

  //! model
  ServerCommandModel& _model( void )
  { return model_; }
  
  private slots:
  
  //! configuration
  void _updateConfiguration( void );
  
  //! store selected jobs in model
  void _storeSelection( void );

  //! restore selected jobs from model
  void _restoreSelection( void );

  //! store expanded jobs in model
  void _storeExpandedItems( void );

  //! restore expanded jobs from model
  void _restoreExpandedItems( void );
  
  //! update actions
  void _updateActions( void );
  
  //! request reset command
  void _requestReset( void );
  
  //! request unlock command
  void _requestUnlock( void );
  
  //! request raise command
  void _requestRaise( void );
  
  //! request abort command
  void _requestAbort( void );
  
  private:

  //! actions
  void _installActions( void );
  
  //! verbosity
  Verbosity verbosity_;
  
  //! menu bar
  Menu* menu_;
  
  //! Command list
  TreeView* list_;
    
  //! command model
  ServerCommandModel model_;

  //! toolbar
  CustomToolBar* toolbar_;
  
  //! state frame
  StatusBar* statusbar_;
  
  //!@name actions
  //@{
  
  //! reset
  QAction* reset_action_;
  
  //! unlock
  QAction* unlock_action_;
  
  //! raise application action
  QAction* raise_action_;
  
  //! abort application action
  QAction* abort_action_;
  
  //@}
  
};

#endif
