// $Id: ServerCommandModel.cpp,v 1.10 2009/04/20 14:18:52 hpereira Exp $

/******************************************************************************
 *                         
 * Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>             
 *                         
 * This is free software; you can redistribute it and/or modify it under the    
 * terms of the GNU General Public License as published by the Free Software    
 * Foundation; either version 2 of the License, or (at your option) any later   
 * version.                             
 *                          
 * This software is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or        
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License        
 * for more details.                     
 *                          
 * You should have received a copy of the GNU General Public License along with 
 * software; if not, write to the Free Software Foundation, Inc., 59 Temple     
 * Place, Suite 330, Boston, MA  02111-1307 USA                           
 *                         
 *                         
 *******************************************************************************/

/*!
  \file    ServerCommandModel.h
  \brief   ServerCommand model. Stores command information for display in lists
  \author  Hugo Pereira
  \version $Revision: 1.10 $
  \date    $Date: 2009/04/20 14:18:52 $
*/

#include <QApplication>

#include "ServerCommandModel.h"
#include "TimeStamp.h"

using namespace std;
using namespace SERVER;

//____________________________________________________
const QString ServerCommandModel::column_titles_[ ServerCommandModel::n_columns ] = 
{
  "Name",
  "User",
  "Display",
  "Command",
  "Time"
};

//_______________________________________________________________
ServerCommandModel::ServerCommandModel( QObject* parent ):
  TreeModel<ServerCommand>( parent ),
  Counter( "ServerCommandModel" )
{
  Debug::Throw( "ServerCommandModel::ServerCommandModel.\n" );
}

//__________________________________________________________________
QVariant ServerCommandModel::data( const QModelIndex& index, int role ) const
{

  Debug::Throw(2) << "ServerCommandModel::data - row: " << index.row() << " column: " << index.column() << " role: " << role << endl;
  
  // check index, role and column
  if( !index.isValid() ) return QVariant();
    
  // return text associated to file and column
  if( role == Qt::DisplayRole ) 
  { 
    
    // retrieve associated file info
    // const ServerCommand& command( get()[index.row()] );
    const ServerCommand& command( _find( index.internalId() ).get() );
    switch( index.column() )
    {
      
      case STAMP: return command.timeStamp().toString();
      case NAME: return command.id().name();
      case USER: return command.id().userName();
      case DISPLAY: return command.id().display();
      case COMMAND: return command.commandName();
      
      default:
      return QVariant(); 
    }
    
  } else if( role == Qt::ForegroundRole ) {
    
    const ServerCommand& command( _find( index.internalId() ).get() );
    if( command.command() == ServerCommand::IDENTIFY && identifyColor().isValid() ) return identifyColor();
    else if( command.command() == ServerCommand::IDENTIFY_SERVER && serverColor().isValid() ) return serverColor();
    else return QVariant();
    
  }
    
  return QVariant();
  
}

//__________________________________________________________________
QVariant ServerCommandModel::headerData(int section, Qt::Orientation orientation, int role) const
{

  if( 
    orientation == Qt::Horizontal && 
    role == Qt::DisplayRole && 
    section >= 0 && 
    section < int(n_columns) )
  { return column_titles_[section]; }
  
  // return empty
  return QVariant(); 

}

//________________________________________________________
bool ServerCommandModel::SortFTor::operator () ( ServerCommand first, ServerCommand second ) const
{
  
  if( order_ == Qt::AscendingOrder ) swap( first, second );
  switch( type_ )
  {
    
    case NAME: return first.id().name() < second.id().name();
    case USER: return first.id().user() < second.id().user();
    case DISPLAY: return first.id().display() < second.id().display();
    case COMMAND: return first.command() == ServerCommand::IDENTIFY_SERVER || first.command() < second.command();
    case STAMP: return first.timeStamp() < second.timeStamp();
    default: return false;
    
  }
 
}
